@@ -22,16 +22,16 @@
 #include "board.h"
 #include "prefs.h"
 
-#include <kdebug.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
+#include <KLocalizedString>
 
+
+#include "kshisen_debug.h"
 #include <QMouseEvent>
 #include <QPainter>
 #include <QTimer>
 
 #include <cstring>
+#include <QStandardPaths>
 
 
 #define EMPTY           0
@@ -45,7 +45,7 @@ bool PossibleMove::isInPath(int x, int y) const
     if (x == m_path.last().x && y == m_path.last().y) {
         return false;
     }
-    kDebug() << "isInPath:" << x << "," << y;
+    qCDebug(KSHISEN_LOG) << "isInPath:" << x << "," << y;
     Debug();
     QList<Position>::const_iterator iter;
     // a path has at least 2 positions
@@ -57,7 +57,7 @@ bool PossibleMove::isInPath(int x, int y) const
         // to fix
         if ((x == iter->x && ((y > pathY && y <= iter->y) || (y < pathY && y >= iter->y)))
                 || (y == iter->y && ((x > pathX && x <= iter->x) || (x < pathX && x >= iter->x)))) {
-            kDebug() << "isInPath:" << x << "," << y << "found in path" << pathX << "," << pathY << " => " << iter->x << "," << iter->y;
+            qCDebug(KSHISEN_LOG) << "isInPath:" << x << "," << y << "found in path" << pathX << "," << pathY << " => " << iter->x << "," << iter->y;
             return true;
         }
         pathX = iter->x;
@@ -76,8 +76,8 @@ Board::Board(QWidget *parent)
       m_gravityFlag(true), m_solvableFlag(false), m_chineseStyleFlag(false), m_tilesCanSlideFlag(false),
       m_highlightedTile(-1),
       m_paintConnection(false), m_paintPossibleMoves(false), m_paintInProgress(false),
-      m_soundPick(KStandardDirs::locate("sound", "kshisen/tile-touch.ogg")),
-      m_soundFall(KStandardDirs::locate("sound", "kshisen/tile-fall-tile.ogg"))
+      m_soundPick(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("sounds/kshisen/tile-touch.ogg"))),
+      m_soundFall(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("sounds/kshisen/tile-fall-tile.ogg")))
 {
     m_tileRemove1.first = -1;
 
@@ -99,12 +99,12 @@ Board::~Board()
 void Board::loadSettings()
 {
     if (!loadTileset(Prefs::tileSet())) {
-        kDebug() << "An error occurred when loading the tileset" << Prefs::tileSet() << "KShisen will continue with the default tileset.";
+        qCDebug(KSHISEN_LOG) << "An error occurred when loading the tileset" << Prefs::tileSet() << "KShisen will continue with the default tileset.";
     }
 
     // Load background
     if (!loadBackground(Prefs::background())) {
-        kDebug() << "An error occurred when loading the background" << Prefs::background() << "KShisen will continue with the default background.";
+        qCDebug(KSHISEN_LOG) << "An error occurred when loading the background" << Prefs::background() << "KShisen will continue with the default background.";
     }
 
     // There are tile sets, that have only one tile for e.g. the flowers group.
@@ -139,7 +139,7 @@ bool Board::loadTileset(const QString &pathToTileset)
     if (m_tiles.loadTileset(pathToTileset)) {
         if (m_tiles.loadGraphics()) {
             Prefs::setTileSet(pathToTileset);
-            Prefs::self()->writeConfig();
+            Prefs::self()->save();
             resizeBoard();
         }
         return true;
@@ -148,7 +148,7 @@ bool Board::loadTileset(const QString &pathToTileset)
     if (m_tiles.loadDefault()) {
         if (m_tiles.loadGraphics()) {
             Prefs::setTileSet(m_tiles.path());
-            Prefs::self()->writeConfig();
+            Prefs::self()->save();
             resizeBoard();
         }
     }
@@ -160,7 +160,7 @@ bool Board::loadBackground(const QString &pathToBackground)
     if (m_background.load(pathToBackground, width(), height())) {
         if (m_background.loadGraphics()) {
             Prefs::setBackground(pathToBackground);
-            Prefs::self()->writeConfig();
+            Prefs::self()->save();
             resizeBoard();
             return true;
         }
@@ -169,7 +169,7 @@ bool Board::loadBackground(const QString &pathToBackground)
     if (m_background.loadDefault()) {
         if (m_background.loadGraphics()) {
             Prefs::setBackground(m_background.path());
-            Prefs::self()->writeConfig();
+            Prefs::self()->save();
             resizeBoard();
         }
     }
@@ -189,8 +189,7 @@ int Board::yTiles() const
 void Board::setField(int x, int y, int value)
 {
     if (x < 0 || y < 0 || x >= xTiles() || y >= yTiles()) {
-        kFatal() << "Attempted write to invalid field position "
-                 "(" << x << "," << y << ")";
+        qFatal("Attempted write to invalid field position (%u,%u)", x, y);
     }
 
     m_field[y * xTiles() + x] = value;
@@ -201,8 +200,7 @@ int Board::field(int x, int y) const
 {
 #ifdef DEBUGGING
     if (x < -1 || y < -1 || x > xTiles() || y > yTiles()) {
-        kFatal() << "Attempted read from invalid field position "
-                 "(" << x << "," << y << ")";
+        qFatal("Attempted read from invalid field position (%u,%u)", x, y);
     }
 #endif
 
@@ -411,9 +409,9 @@ void Board::setSize(int x, int y)
 
 void Board::resizeEvent(QResizeEvent *e)
 {
-    kDebug() << "[resizeEvent]";
+    qCDebug(KSHISEN_LOG) << "[resizeEvent]";
     if (e->spontaneous()) {
-        kDebug() << "[resizeEvent] spontaneous";
+        qCDebug(KSHISEN_LOG) << "[resizeEvent] spontaneous";
     }
     resizeBoard();
     emit resized();
@@ -557,7 +555,7 @@ void Board::newGame()
     }
     // debug, tell if make solvable failed
     if (maxAttempts == 0) {
-        kDebug() << "NewGame make solvable failed";
+        qCDebug(KSHISEN_LOG) << "NewGame make solvable failed";
     }
 
 
@@ -880,7 +878,7 @@ void Board::performMove(PossibleMove &possibleMoves)
         // DEBUG undo, compare to saved board state
         for (int i = 0; i < xTiles() * yTiles(); ++i) {
             if (saved1[i] != m_field[i]) {
-                kDebug() << "[DEBUG Undo 1], tile (" << i << ") was" << saved1[i] << "before more, it is" << m_field[i] << "after undo.";
+                qCDebug(KSHISEN_LOG) << "[DEBUG Undo 1], tile (" << i << ") was" << saved1[i] << "before more, it is" << m_field[i] << "after undo.";
                 errorFound = true;
             }
         }
@@ -893,7 +891,7 @@ void Board::performMove(PossibleMove &possibleMoves)
             // DEBUG undo, compare to saved board2 state
             for (int i = 0; i < xTiles() * yTiles(); ++i) {
                 if (saved2[i] != m_field[i]) {
-                    kDebug() << "[DEBUG Undo 2], tile (" << i << ") was" << saved2[i] << "after more, it is" << m_field[i] << "after redo.";
+                    qCDebug(KSHISEN_LOG) << "[DEBUG Undo 2], tile (" << i << ") was" << saved2[i] << "after more, it is" << m_field[i] << "after redo.";
                     errorFound = true;
                 }
             }
@@ -903,13 +901,13 @@ void Board::performMove(PossibleMove &possibleMoves)
     }
     // dumpBoard on error
     if (errorFound) {
-        kDebug() << "[DEBUG] Before move";
+        qCDebug(KSHISEN_LOG) << "[DEBUG] Before move";
         dumpBoard(saved1);
-        kDebug() << "[DEBUG] After move";
+        qCDebug(KSHISEN_LOG) << "[DEBUG] After move";
         dumpBoard(saved2);
-        kDebug() << "[DEBUG] Undo";
+        qCDebug(KSHISEN_LOG) << "[DEBUG] Undo";
         dumpBoard(saved3);
-        kDebug() << "[DEBUG] Redo";
+        qCDebug(KSHISEN_LOG) << "[DEBUG] Redo";
         dumpBoard(saved4);
     }
 
@@ -1485,7 +1483,7 @@ void Board::undo()
         // if there is no slide, keep previous implementation: move both column up
         if (!move->m_hasSlide) {
 #ifdef DEBUGGING
-            kDebug() << "[undo] gravity from a no slide move";
+            qCDebug(KSHISEN_LOG) << "[undo] gravity from a no slide move";
 #endif
             // move tiles from the first column up
             for (y = 0; y < move->m_y1; ++y) {
@@ -1500,7 +1498,7 @@ void Board::undo()
             }
         } else { // else check all tiles from the slide that may have fallen down
 #ifdef DEBUGGING
-            kDebug() << "[undo] gravity from slide s1(" << move->m_slideX1 << "," << move->m_slideY1 << ")=>s2(" << move->m_slideX2 << "," << move->m_slideY2 << ") matching (" << move->m_x1 << "," << move->m_y1 << ")=>(" << move->m_x2 << "," << move->m_y2 << ")";
+            qCDebug(KSHISEN_LOG) << "[undo] gravity from slide s1(" << move->m_slideX1 << "," << move->m_slideY1 << ")=>s2(" << move->m_slideX2 << "," << move->m_slideY2 << ") matching (" << move->m_x1 << "," << move->m_y1 << ")=>(" << move->m_x2 << "," << move->m_y2 << ")";
 #endif
             // horizontal slide
             // because tiles that slides horizontaly may fall down
@@ -1508,7 +1506,7 @@ void Board::undo()
             // we need to take them back up then undo the slide
             if (move->m_slideY1 == move->m_slideY2) {
 #ifdef DEBUGGING
-                kDebug() << "[undo] gravity from horizontal slide";
+                qCDebug(KSHISEN_LOG) << "[undo] gravity from horizontal slide";
 #endif
                 // last slide tile went from slide_x1 -> slide_x2
                 // the number of slided tiles is n = abs(x1 - slide_x1)
@@ -1522,14 +1520,14 @@ void Board::undo()
                     dx = -dx;
                 }
 #ifdef DEBUGGING
-                kDebug() << "[undo] n =" << n;
+                qCDebug(KSHISEN_LOG) << "[undo] n =" << n;
 #endif
                 // slided tiles may fall down after the slide
                 // so any tiles on top of the columns between
                 // slide_x2 -> slide_x2 +/- n (excluded) should go up to slide_y1
                 if (move->m_slideX2 > move->m_slideX1) {  // slide to the right
 #ifdef DEBUGGING
-                    kDebug() << "[undo] slide right";
+                    qCDebug(KSHISEN_LOG) << "[undo] slide right";
 #endif
                     for (int i = move->m_slideX2; i > move->m_slideX2 - n; --i) {
                         // find top tile
@@ -1545,7 +1543,7 @@ void Board::undo()
                             continue;
                         }
 #ifdef DEBUGGING
-                        kDebug() << "[undo] moving (" << i << "," << j << ") up to (" << i << "," << move->m_slideY1 << ")";
+                        qCDebug(KSHISEN_LOG) << "[undo] moving (" << i << "," << j << ") up to (" << i << "," << move->m_slideY1 << ")";
 #endif
                         // put it back up
                         setField(i, move->m_slideY1, field(i, j));
@@ -1555,7 +1553,7 @@ void Board::undo()
                     }
                 } else { // slide to the left
 #ifdef DEBUGGING
-                    kDebug() << "[undo] slide left";
+                    qCDebug(KSHISEN_LOG) << "[undo] slide left";
 #endif
                     for (int i = move->m_slideX2; i < move->m_slideX2 + n; ++i) {
                         // find top tile
@@ -1571,7 +1569,7 @@ void Board::undo()
                             continue;
                         }
 #ifdef DEBUGGING
-                        kDebug() << "[undo] moving (" << i << "," << j << ") up to (" << i << "," << move->m_slideY1 << ")";
+                        qCDebug(KSHISEN_LOG) << "[undo] moving (" << i << "," << j << ") up to (" << i << "," << move->m_slideY1 << ")";
 #endif
                         // put it back up
                         setField(i, move->m_slideY1, field(i, j));
@@ -1582,11 +1580,11 @@ void Board::undo()
                 }
                 // move tiles from the second column up
 #ifdef DEBUGGING
-                kDebug() << "[undo] moving up column x2" << move->m_x2;
+                qCDebug(KSHISEN_LOG) << "[undo] moving up column x2" << move->m_x2;
 #endif
                 for (y = 0; y <= move->m_y2; ++y) {
 #ifdef DEBUGGING
-                    kDebug() << "[undo] moving up tile" << y + 1;
+                    qCDebug(KSHISEN_LOG) << "[undo] moving up tile" << y + 1;
 #endif
                     setField(move->m_x2, y, field(move->m_x2, y + 1));
                     updateField(move->m_x2, y);
@@ -1600,17 +1598,17 @@ void Board::undo()
                     if (move->m_slideY1 > 0) {
                         for (int i = move->m_x1 + dx; i >= move->m_x1; --i) {
 #ifdef DEBUGGING
-                            kDebug() << "[undo] moving up column" << i << "until" << move->m_slideY1;
+                            qCDebug(KSHISEN_LOG) << "[undo] moving up column" << i << "until" << move->m_slideY1;
 #endif
                             for (int j = 0; j < move->m_slideY1; ++j) {
 #ifdef DEBUGGING
-                                kDebug() << "[undo] moving up tile" << j + 1;
+                                qCDebug(KSHISEN_LOG) << "[undo] moving up tile" << j + 1;
 #endif
                                 setField(i, j, field(i, j + 1));
                                 updateField(i, j);
                             }
 #ifdef DEBUGGING
-                            kDebug() << "[undo] clearing last tile" << move->m_slideY1;
+                            qCDebug(KSHISEN_LOG) << "[undo] clearing last tile" << move->m_slideY1;
 #endif
                             setField(i, move->m_slideY1, EMPTY);
                             updateField(i, move->m_slideY1);
@@ -1620,17 +1618,17 @@ void Board::undo()
                     if (move->m_slideY1 > 0) {
                         for (int i = move->m_x1 - dx; i <= move->m_x1; ++i) {
 #ifdef DEBUGGING
-                            kDebug() << "[undo] moving up column" << i << "until" << move->m_slideY1;
+                            qCDebug(KSHISEN_LOG) << "[undo] moving up column" << i << "until" << move->m_slideY1;
 #endif
                             for (int j = 0; j < move->m_slideY1; ++j) {
 #ifdef DEBUGGING
-                                kDebug() << "[undo] moving up tile" << j + 1;
+                                qCDebug(KSHISEN_LOG) << "[undo] moving up tile" << j + 1;
 #endif
                                 setField(i, j, field(i, j + 1));
                                 updateField(i, j);
                             }
 #ifdef DEBUGGING
-                            kDebug() << "[undo] clearing last tile" << move->m_slideY1;
+                            qCDebug(KSHISEN_LOG) << "[undo] clearing last tile" << move->m_slideY1;
 #endif
                             setField(i, move->m_slideY1, EMPTY);
                             updateField(i, move->m_slideY1);
@@ -1640,7 +1638,7 @@ void Board::undo()
 
                 // then undo the slide to put the tiles back to their original location
 #ifdef DEBUGGING
-                kDebug() << "[undo] reversing slide";
+                qCDebug(KSHISEN_LOG) << "[undo] reversing slide";
 #endif
                 reverseSlide(move->m_x1, move->m_y1, move->m_slideX1, move->m_slideY1, move->m_slideX2, move->m_slideY2);
 
@@ -1649,7 +1647,7 @@ void Board::undo()
                 // the default implementation works because it only affects
                 // the two columns were tiles were taken
 #ifdef DEBUGGING
-                kDebug() << "[undo] gravity from vertical slide";
+                qCDebug(KSHISEN_LOG) << "[undo] gravity from vertical slide";
 #endif
 
                 // move tiles from the first column up
@@ -1733,7 +1731,7 @@ void Board::makeHintMove()
 
 void Board::dumpBoard() const
 {
-    kDebug() << "Board contents:";
+    qCDebug(KSHISEN_LOG) << "Board contents:";
     for (int y = 0; y < yTiles(); ++y) {
         QString row;
         for (int x = 0; x < xTiles(); ++x) {
@@ -1744,13 +1742,13 @@ void Board::dumpBoard() const
                 row += QString("%1").arg(tile, 3);
             }
         }
-        kDebug() << row;
+        qCDebug(KSHISEN_LOG) << row;
     }
 }
 
 void Board::dumpBoard(const int *board) const
 {
-    kDebug() << "Board contents:";
+    qCDebug(KSHISEN_LOG) << "Board contents:";
     for (int y = 0; y < yTiles(); ++y) {
         QString row;
         for (int x = 0; x < xTiles(); ++x) {
@@ -1761,7 +1759,7 @@ void Board::dumpBoard(const int *board) const
                 row += QString("%1").arg(tile, 3);
             }
         }
-        kDebug() << row;
+        qCDebug(KSHISEN_LOG) << row;
     }
 }
 #endif
@@ -1837,10 +1835,15 @@ bool Board::solvable(bool noRestore)
 
     PossibleMoves p;
     while (hint_I(p)) {
-        kFatal(!tilesMatch(field(p.first().m_path.first().x, p.first().m_path.first().y), field(p.first().m_path.last().x, p.first().m_path.last().y)))
-                << "Removing unmatched tiles: (" << p.first().m_path.first().x << "," << p.first().m_path.first().y << ") => "
-                << field(p.first().m_path.first().x, p.first().m_path.first().y) << " (" << p.first().m_path.last().x << "," << p.first().m_path.last().y << ") => "
-                << field(p.first().m_path.last().x, p.first().m_path.last().y);
+        if (!tilesMatch(field(p.first().m_path.first().x, p.first().m_path.first().y), field(p.first().m_path.last().x, p.first().m_path.last().y))) {
+            qFatal("Removing unmatched tiles: (%u,%u) => %u (%u,%u) => %u",
+                   p.first().m_path.first().x,
+                   p.first().m_path.first().y,
+                   field(p.first().m_path.first().x, p.first().m_path.first().y),
+                   p.first().m_path.last().x,
+                   p.first().m_path.last().y,
+                   field(p.first().m_path.last().x, p.first().m_path.last().y));
+        }
         setField(p.first().m_path.first().x, p.first().m_path.first().y, EMPTY);
         setField(p.first().m_path.last().x, p.first().m_path.last().y, EMPTY);
     }
@@ -2017,10 +2020,9 @@ bool Board::hasCheated() const
 void Board::setSoundsEnabled(bool enabled)
 {
     Prefs::setSounds(enabled);
-    Prefs::self()->writeConfig();
+    Prefs::self()->save();
 }
 
-#include "board.moc"
 
 // vim: expandtab:tabstop=4:shiftwidth=4
 // kate: space-indent on; indent-width 4
